@@ -15,20 +15,17 @@
 # along with lazr.enum.  If not, see <http://www.gnu.org/licenses/>.
 """Enumerations."""
 
-__version__ = '1.1'
+import pkg_resources
+__version__ = pkg_resources.resource_string(
+    "lazr.enum", "version.txt").strip()
 
-# Re-export in such a way that __version__ can still be imported if
-# dependencies are not yet available.
-try:
-    # While we generally frown on "*" imports, this, combined with the fact we
-    # only test code from this module, means that we can verify what has been
-    # exported.
-    from lazr.enum._enum import *
-    from lazr.enum._enum import __all__ as _all
-    from lazr.enum.interfaces import *
-    from lazr.enum.interfaces import __all__ as _iall
-    __all__ = []
-    __all__.extend(_all)
-    __all__.extend(_iall)
-except ImportError:
-    pass
+# While we generally frown on "*" imports, this, combined with the fact we
+# only test code from this module, means that we can verify what has been
+# exported.
+from lazr.enum._enum import *
+from lazr.enum._enum import __all__ as _all
+from lazr.enum.interfaces import *
+from lazr.enum.interfaces import __all__ as _iall
+__all__ = []
+__all__.extend(_all)
+__all__.extend(_iall)
