@@ -122,8 +122,9 @@ class BaseItem:
     name = None
     description = None
     title = None
+    url = None
 
-    def __init__(self, title, description=None):
+    def __init__(self, title, description=None, url=None):
         """Items are the main elements of the EnumeratedType.
 
         Where the title is passed in without a description,
@@ -138,6 +139,7 @@ class BaseItem:
         # containing enumerated type.
 
         self.description = description
+        self.url = url
 
         if self.description is None:
             # check value
@@ -181,7 +183,7 @@ class Item(BaseItem):
     @staticmethod
     def construct(other_item):
         """Create an Item based on the other_item."""
-        item = Item(other_item.title, other_item.description)
+        item = Item(other_item.title, other_item.description, other_item.url)
         item.sortkey = other_item.sortkey
         return item
 
@@ -199,13 +201,13 @@ class DBItem(BaseItem):
     @staticmethod
     def construct(other_item):
         """Create an Item based on the other_item."""
-        item = DBItem(
-            other_item.value, other_item.title, other_item.description)
+        item = DBItem(other_item.value, other_item.title, 
+                      other_item.description, other_item.url)
         item.sortkey = other_item.sortkey
         return item
 
-    def __init__(self, value, title, description=None):
-        BaseItem.__init__(self, title, description)
+    def __init__(self, value, title, description=None, url=None):
+        BaseItem.__init__(self, title, description, url)
         self.value = value
 
     def __hash__(self):
